'''there are 7 modules in this package you have teh DataBase class, DataDiscovery,
DataVisulization, DataCorrelation, Encoder, MissingValues, FeatureScaler'''
from .datadiscovery import DataDiscovery
from .datacorrelation import DataCorrelation
from .encoder2 import Encoder
from .missingvalues import MissingValues
from .featur_scaling import FeatureScaler
from .inconsistent_data import InconsistentData
from .stringtodatetime import StringToDateTime
from .resource import Resources
